summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2019-12-10 20:04:36 -0800
committerPaul Eggert <eggert@cs.ucla.edu>2019-12-10 20:05:49 -0800
commitb0f20651e3cbb8a66f11ffae4c18634019c20cd4 (patch)
tree067bcb8fa529b4afee6d189f409faf16bd437810 /src
parent0940296ebe56ebdf9c32e94191d4f0b18006a910 (diff)
downloademacs-b0f20651e3cbb8a66f11ffae4c18634019c20cd4.tar.gz
emacs-b0f20651e3cbb8a66f11ffae4c18634019c20cd4.tar.bz2
emacs-b0f20651e3cbb8a66f11ffae4c18634019c20cd4.zip
; Spelling fixes
Diffstat (limited to 'src')
-rw-r--r--src/hbfont.c6
-rw-r--r--src/window.c2
-rw-r--r--src/xdisp.c4
3 files changed, 6 insertions, 6 deletions
diff --git a/src/hbfont.c b/src/hbfont.c
index 5a057c26a1d..2150b6656e1 100644
--- a/src/hbfont.c
+++ b/src/hbfont.c
@@ -358,8 +358,8 @@ get_hb_unicode_funcs (void)
hb_unicode_funcs_set_general_category_func (funcs, uni_general, NULL, NULL);
hb_unicode_funcs_set_mirroring_func (funcs, uni_mirroring, NULL, NULL);
- /* Use default implmentation for Unicode composition/decomposition, we might
- * want to revisit this later.
+ /* Use default implementation for Unicode composition/decomposition.
+ We might want to revisit this later.
hb_unicode_funcs_set_compose_func (funcs, uni_compose, NULL, NULL);
hb_unicode_funcs_set_decompose_func (funcs, uni_decompose, NULL, NULL);
*/
@@ -379,7 +379,7 @@ get_hb_unicode_funcs (void)
(N+1)th element of LGSTRING is nil, input of shaping is from the
1st to (N)th elements. In each input glyph, FROM, TO, CHAR, and
CODE are already set, but FROM and TO need adjustments according
- to the glyphs produced by the shaping fuinction.
+ to the glyphs produced by the shaping function.
DIRECTION is either L2R or R2L, or nil if unknown. During
redisplay, this comes from applying the UBA, is passed from
composition_reseat_it, and is used by the HarfBuzz shaper.
diff --git a/src/window.c b/src/window.c
index 1984a540add..c52a8ca2855 100644
--- a/src/window.c
+++ b/src/window.c
@@ -7617,7 +7617,7 @@ set_window_fringes (struct window *w,
else
failed = true;
- /* Placing fringes ouside margins. */
+ /* Placing fringes outside margins. */
if (outside != w->fringes_outside_margins)
{
w->fringes_outside_margins = outside;
diff --git a/src/xdisp.c b/src/xdisp.c
index 2467b336f4a..08c6927052c 100644
--- a/src/xdisp.c
+++ b/src/xdisp.c
@@ -21693,7 +21693,7 @@ extend_face_to_end_of_line (struct it *it)
&& indicator_column < it->last_visible_x)
{
/* Here we substract char_width because we want the
column indicator in the column INDICATOR_COLUMN,
not after it. */
const int stretch_width =
@@ -21865,7 +21865,7 @@ extend_face_to_end_of_line (struct it *it)
/* We need to subtract 1 to the indicator_column here because we
will add the indicator IN the column indicator number, not
after it. We compare the variable it->current_x before
- producing the glyph. When FRAME_WINDOW_P we substract
+ producing the glyph. When FRAME_WINDOW_P we subtract
CHAR_WIDTH calculating STRETCH_WIDTH for the same reason. */
const int indicator_column =
fill_column_indicator_column (it, 1) - 1;
@@ -21693,7 +21693,7 @@ extend_face_to_end_of_line (struct it *it)
&& indicator_column < it->last_visible_x)
{
- /* Here we substract char_width because we want the
+ /* Here we subtract char_width because we want the
column indicator in the column INDICATOR_COLUMN,
not after it. */